Create a connection using a pre-configured ODBC DSN
create_dsn_connection.RdEstablishes a connection to a database using a pre-configured ODBC Data Source Name (DSN). This is useful for databases that use Windows authentication or other authentication methods not requiring credentials in R. Commonly used for SQL Server databases like PIRO LOTUS observer database.
Examples
if (FALSE) { # \dontrun{
# Connect to PIRO LOTUS observer database
con <- create_dsn_connection("PIRO LOTUS")
DBI::dbListTables(con)
DBI::dbDisconnect(con)
} # }